.. greatday

Welcome to greatday's documentation!
====================================

Don't have a good day. Have a great day.

.. toctree::
   :maxdepth: -1
   :caption: Table of Contents

    API Reference <modules>
    Changelog <changelog>
    Development Guide <contributing>
    README <readme>


Indices and Tables
==================

* :ref:`genindex`
* :ref:`modindex`
